{% spaceless %}
{% if file.file_type == 'Image' %}
    <img src="{{ file.url }}" alt="{{ file.default_alt_text }}" title="{{ file.default_caption }}">
{% elif file.file_type == 'File' %}
    <a href="{{ file.url }}">{{ file.url }}</a>
{% else %}
    <!-- {{ file.file_type }} not supported. -->
{% endif %}
{% endspaceless %}