/**
 * Bootstrap-Markdown.less
 *
 * @author Taufan Aditya @taufanaditya
 * @copyright 2013 Taufan Aditya
 */
@font-face {
  font-family: "markdown-editor";
  src: url("../font/markdown-editor.eot");
  src: url("../font/markdown-editor.eot#iefix") format("embedded-opentype"), url("../font/markdown-editor.woff") format("woff"), url("../font/markdown-editor.ttf") format("truetype"), url("../font/markdown-editor.svg#markdown-editor") format("svg");
  font-weight: normal;
  font-style: normal;
}
.md-editor {
  display: block;
  border: 1px solid #dddddd;
}
.md-editor > .md-header,
.md-editor .md-footer {
  display: block;
  padding: 6px 4px;
  background: #f5f5f5;
}
.md-editor > .md-header {
  margin: 0;
}
.md-editor > .md-header > .btn-group {
  display: inline-block;
  margin: 0 10px;
}
.md-editor > .md-header > .btn-group:first-child {
  margin-left: 0;
}
.md-editor > .md-preview {
  background: #ffffff;
  border-top: 1px dashed #dddddd;
  border-bottom: 1px dashed #dddddd;
  min-height: 10px;
  overflow: auto;
}
.md-editor > textarea {
  font-family: Menlo, Monaco, Consolas, "Courier New", monospace;
  font-size: 14px;
  outline: 0;
  outline: thin dotted  \9;
  /* IE6-9 */
  margin: 0;
  display: block;
  padding: 0;
  width: 100%;
  border: 0;
  border-top: 1px dashed #dddddd;
  border-bottom: 1px dashed #dddddd;
  border-radius: 0;
  box-shadow: none;
  background: #eeeeee;
}
.md-editor > textarea:focus {
  box-shadow: none;
  background: #ffffff;
}
.md-editor.active {
  border-color: #66afe9;
  outline: 0;
  -webkit-box-shadow: inset 0 1px 1px rgba(0,0,0,.075), 0 0 8px rgba(102, 175, 233, 0.6);
  -moz-box-shadow: inset 0 1px 1px rgba(0,0,0,.075), 0 0 8px rgba(102, 175, 233, 0.6);
  -ms-box-shadow: inset 0 1px 1px rgba(0,0,0,.075), 0 0 8px rgba(102, 175, 233, 0.6);
  -o-box-shadow: inset 0 1px 1px rgba(0,0,0,.075), 0 0 8px rgba(102, 175, 233, 0.6);
  box-shadow: inset 0 1px 1px rgba(0,0,0,.075), 0 0 8px rgba(102, 175, 233, 0.6);
}
.md-editor .md-controls {
  float: right;
  padding: 3px;
}
.md-editor .md-controls .md-control {
  right: 5px;
  color: #bebebe;
  padding: 3px 3px 3px 10px;
}
.md-editor .md-controls .md-control:hover {
  color: #333;
}
.md-editor.md-fullscreen-mode {
  width: 100%;
  height: 100%;
  position: fixed;
  top: 0;
  left: 0;
  z-index: 99999;
  padding: 60px 30px 15px;
  background: #fff !important;
  border: 0 !important;
}
.md-editor.md-fullscreen-mode .md-footer {
  display: none;
}
.md-editor.md-fullscreen-mode .md-input,
.md-editor.md-fullscreen-mode .md-preview {
  margin: 0 auto !important;
  height: 100% !important;
  font-size: 20px !important;
  padding: 20px !important;
  color: #999;
  line-height: 1.6em !important;
  resize: none !important;
  box-shadow: none !important;
  background: #fff !important;
  border: 0 !important;
}
.md-editor.md-fullscreen-mode .md-preview {
  color: #333;
  overflow: auto;
}
.md-editor.md-fullscreen-mode .md-input:hover,
.md-editor.md-fullscreen-mode .md-input:focus {
  color: #333;
  background: #fff !important;
}
.md-editor.md-fullscreen-mode .md-header {
  background: none;
  text-align: center;
  position: fixed;
  width: 100%;
  top: 20px;
}
.md-editor.md-fullscreen-mode .btn-group {
  float: none;
}
.md-editor.md-fullscreen-mode .btn {
  border: 0;
  background: none;
  color: #b3b3b3;
}
.md-editor.md-fullscreen-mode .btn:hover,
.md-editor.md-fullscreen-mode .btn:focus,
.md-editor.md-fullscreen-mode .btn.active,
.md-editor.md-fullscreen-mode .btn:active {
  box-shadow: none;
  color: #333;
}
.md-editor.md-fullscreen-mode .md-fullscreen-controls {
  position: absolute;
  top: 20px;
  right: 20px;
  text-align: right;
  z-index: 1002;
  display: block;
}
.md-editor.md-fullscreen-mode .md-fullscreen-controls a {
  color: #b3b3b3;
  clear: right;
  margin: 10px;
  width: 30px;
  height: 30px;
  text-align: center;
}
.md-editor.md-fullscreen-mode .md-fullscreen-controls a:hover {
  color: #333;
  text-decoration: none;
}
.md-editor.md-fullscreen-mode .md-editor {
  height: 100% !important;
  position: relative;
}
.md-editor .md-fullscreen-controls {
  display: none;
}
.md-editor .btn {
  display: inline-block;
  border: solid 1px #ccc;
  border-radius: 2px;
  padding: 5px 10px;
  margin: 0 2px;
}
.md-editor .btn.hidden {
  display: none;
}
.md-editor .glyphicon:before {
  font-family: "markdown-editor";
}
.md-editor .glyphicon-bold:before {
    content: '\e800';
}
.md-editor .glyphicon-italic:before {
    content: '\e801';
}
.md-editor .glyphicon-header:before {
    content: '\e802';
}
.md-editor .glyphicon-picture:before {
    content: '\e803';
}
.md-editor .glyphicon-list-bullet:before {
    content: '\e804';
}
.md-editor .glyphicon-list-numbered:before {
    content: '\e805';
}
.md-editor .glyphicon-asterisk:before {
    content: '\e806';
}
.md-editor .glyphicon-comment:before {
    content: '\e807';
}
.md-editor .glyphicon-search:before {
    content: '\e808';
}
.md-editor .glyphicon-minus:before {
    content: '\e809';
}
.md-editor .glyphicon-bug:before {
    content: '\e80a';
}
.md-editor .glyphicon-fullscreen-on:before {
    content: '\e80b';
}
.md-editor .glyphicon-fullscreen-off:before {
    content: '\e80c';
}
.md-editor .glyphicon-link:before {
    content: '\e80d';
}

.md-nooverflow {
  overflow: hidden;
  position: fixed;
  width: 100%;
}
