DEFAULT_MARKYMARK_EXTENSIONS = [
    'markymark.extensions.autolink',
]


DEFAULT_MARKYMARK_TEMPLATES = {
    'filer': 'markdown/file.html',
    'anylink': 'markdown/anylink.html',
    'autolink': 'markdown/autolink.html',
}
